//
//  CoffeeSelectorViewController.swift
//  Desayuno
//
//  Created by Santiago Pavón on 19/04/15.
//  Copyright (c) 2015 UPM. All rights reserved.
//

import UIKit

// Este VC usa delegacion para devolver el valor seleccionado

protocol CoffeeSelectorViewControllerDelegate: class {
    
    func coffeeSelectorViewControllerWasCancelled(csvc: CoffeeSelectorViewController)
    func coffeeSelectorViewController(csvc: CoffeeSelectorViewController,
                                    preferredCoffee coffee: String)
}

class CoffeeSelectorViewController: UIViewController, UITextFieldDelegate {

    var currentCoffee = ""
    
    weak var delegate: CoffeeSelectorViewControllerDelegate!
    
    @IBOutlet weak var coffeeTextField: UITextField!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        coffeeTextField.text = currentCoffee
        coffeeTextField.delegate = self
    }

    
    // MARK: Acciones de los botones
    
    @IBAction func ok() {
        delegate.coffeeSelectorViewController(self, preferredCoffee: coffeeTextField.text!)
    }

    @IBAction func cancel() {
        delegate.coffeeSelectorViewControllerWasCancelled(self)
    }
    
    // MARK: Text Field Delegate
    
    func textFieldShouldReturn(textField: UITextField) -> Bool {
        
        hideKeyboard()
        return true
    }
    
    // MARK: Eventos: al tocar el fondo se oculta el teclado
    
    // He cambiado en el storyboard la clase de la UIView del fondo a UIControl
    
    @IBAction func hideKeyboard() {
     
        // Dejo de ser el primer responder, por lo que se oculta el teclado
        coffeeTextField.resignFirstResponder()
    }
}
